@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.019_02';
+our $VERSION = '0.021_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -278,8 +278,10 @@ sub _keyword {
 
     $pcdata =~ s/\s*$//;
 
-    if(my $system_provides = $self->config('system_provides')->{$keyword}) {
-      $pcdata = length $pcdata ? "$pcdata $system_provides" : $system_provides;
+    if($self->config('system_provides')) {
+      if(my $system_provides = $self->config('system_provides')->{$keyword}) {
+        $pcdata = length $pcdata ? "$pcdata $system_provides" : $system_provides;
+      }
     }
 
     return $pcdata;
@@ -654,6 +656,28 @@ Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Ba
 
 =back
 
+Thanks also to
+
+=over
+
+=item Christian Walde (Mithaldu)
+
+For productive conversations about component interoperablility.
+
+=item kmx
+
+For writing Alien::Tidyp from which I drew many of my initial ideas.
+
+=item David Mertens (run4flat)
+
+For productive conversations about implementation.
+
+=item Mark Nunberg (mordy, mnunberg)
+
+For graciously teaching me about rpath and dynamic loading,
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2012-2015 by Joel Berger
